# -*- coding: utf-8 -*-

# miniview.py
# Version: 1.0  for python v.3.x

# Author: Vincent Vande Vyvre <vincent.vandevyvre@swing.be>
# Licence: GPL3

import sys

from PyQt4 import QtCore, QtGui

class MiniView(object):
    def setupUi(self, MainWindow, main):
        self.MainWindow = MainWindow
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(700, 500)
        MainWindow.setWindowTitle("miniView")
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.gridLayout = QtGui.QGridLayout(self.centralwidget)
        self.verticalLayout = QtGui.QVBoxLayout()
        self.viewer = Viewer(self, self.centralwidget)
        self.verticalLayout.addWidget(self.viewer)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.image_btn = QtGui.QPushButton(self.centralwidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("medias/open.png"),
                                    QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.image_btn.setIcon(icon1)
        self.image_btn.setIconSize(QtCore.QSize(32, 30))
        self.image_btn.setText("Image")
        self.horizontalLayout.addWidget(self.image_btn)
        self.magnifier_btn = QtGui.QToolButton(self.centralwidget)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("medias/magnifier_36x30.png"),
                                    QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.magnifier_btn.setIcon(icon2)
        self.magnifier_btn.setIconSize(QtCore.QSize(32, 30))
        self.horizontalLayout.addWidget(self.magnifier_btn)
        self.label = QtGui.QLabel(self.centralwidget)
        self.horizontalLayout.addWidget(self.label)
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
                                QtGui.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.close_btn = QtGui.QPushButton(self.centralwidget)
        self.close_btn.setText("Quitter")
        self.horizontalLayout.addWidget(self.close_btn)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.gridLayout.addLayout(self.verticalLayout, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 640, 25))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.close_btn.clicked.connect(sys.exit)
        self.image_btn.clicked.connect(self.get_image_file)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.show()
        QtCore.QCoreApplication.processEvents()

        self.scene = QtGui.QGraphicsScene()
        self.viewer.setScene(self.scene)

    def get_image_file(self):
        img = str(QtGui.QFileDialog.getOpenFileName(self.MainWindow,
                                    "Ouverture de fichiers",
                                    "", "Image Files (*.png *.jpg *.bmp)"))
        if not img:
            return
        self.open_image(img)

    def open_image(self, path):
        self.image = QtGui.QImage(path)
        if self.image.isNull():
            self.statusbar.showMessage("Can't open file: {0}".format(path))
            return
        self.zoom = self.viewer.height() / float(self.image.height())
        self.set_pixmap()

    def set_pixmap(self):
        w_img, h_img = int(self.image.width() * self.zoom), \
                                    int(self.image.height() * self.zoom)
        self.pix = QtGui.QPixmap.fromImage(self.image.scaled(w_img, h_img,
                                            QtCore.Qt.KeepAspectRatio,
                                            QtCore.Qt.SmoothTransformation))
        if self.pix.isNull():
            self.statusbar.showMessage("Can't create pixmap")
            return
        self.scene.clear()
        self.scene.setSceneRect(0, 0, w_img, h_img)
        self.scene.addPixmap(self.pix)


class Viewer(QtGui.QGraphicsView):
    def __init__(self, main, parent):
        super(Viewer, self).__init__(parent)
        self.main = main
        self.setDragMode(QtGui.QGraphicsView.ScrollHandDrag)
        self.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)

    def mousePressEvent(self, e):
        QtGui.QGraphicsView.mousePressEvent(self, e)
        e.ignore()

    def mouseButtonRelease(self, e):
        e.ignore()

    def mouseMoveEvent(self, e):
        QtGui.QGraphicsView.mouseMoveEvent(self, e)
        e.ignore()

    def wheelEvent(self, event):
        step = event.delta() / 120
        self.main.zoom += 0.06 * step
        self.main.set_pixmap()

    def keyPressEvent(self, e):
        QtGui.QGraphicsView.keyPressEvent(self, e)
        e.ignore()

if __name__ == "__main__":
    app = QtGui.QApplication(sys.argv)
    MainWindow = QtGui.QMainWindow()
    ui = MiniView()
    ui.setupUi(MainWindow)
    sys.exit(app.exec_())

